#!/bin/sh
#
# /etc/init.d/adeona
#   and its symbolic link
# /(usr/)sbin/rcadeona
#
### BEGIN INIT INFO
# Provides:          adeona
# Required-Start:    $network $remote_fs
# Should-Start:
# Required-Stop:     $network $remote_fs
# Should-Stop:
# Default-Start:     3 5
# Default-Stop:      0 1 2 6
# Short-Description: Adeona daemon
# Description:       Adeona daemon
### END INIT INFO


# Check for missing binaries (stale symlinks should not happen)
# Note: Special treatment of stop for LSB conformance
ADEONA_BIN=/usr/sbin/adeona-client
test -x $ADEONA_BIN || { echo "$ADEONA_BIN not installed"; 
	if [ "$1" = "stop" ]; then exit 0;
	else exit 5; fi; }

ADEONA_STATE=/var/lib/adeona/adeona-clientstate.cst
test -r $ADEONA_STATE || {
	echo "$ADEONA_STATE does not exist";
	echo "Please initialize Adeona first.";
	echo "See /usr/share/doc/packages/adeona/Readme.SuSE for details!";
	if [ "$1" = "stop" ]; then exit 0;
	else exit 6; fi;
}

ADEONA_LOGS=/var/log/adeona/
ADEONA_STATE=/var/lib/adeona/adeona-clientstate.cst
ADEONA_RESOURCES=/usr/share/adeona/

. /etc/rc.status

# Reset status of this service
rc_reset

case "$1" in
    start)
	echo -n "Starting adeona "
	## Start daemon with startproc(8). If this fails
	## the return value is set appropriately by startproc.
	/sbin/startproc $ADEONA_BIN -s $ADEONA_STATE -r $ADEONA_RESOURCES -l $ADEONA_LOGS

	# Remember status and be verbose
	rc_status -v
	;;
    stop)
	echo -n "Shutting down adeona "
	## Stop daemon with killproc(8) and if this fails
	## killproc sets the return value according to LSB.

	/sbin/killproc -TERM $ADEONA_BIN

	# Remember status and be verbose
	rc_status -v
	;;
    try-restart|condrestart)
	## Do a restart only if the service was active before.
	## Note: try-restart is now part of LSB (as of 1.9).
	## RH has a similar command named condrestart.
	if test "$1" = "condrestart"; then
		echo "${attn} Use try-restart ${done}(LSB)${attn} rather than condrestart ${warn}(RH)${norm}"
	fi
	$0 status
	if test $? = 0; then
		$0 restart
	else
		rc_reset	# Not running is not a failure.
	fi
	# Remember status and be quiet
	rc_status
	;;
    restart)
	## Stop the service and regardless of whether it was
	## running or not, start it again.
	$0 stop
	$0 start

	# Remember status and be quiet
	rc_status
	;;
    status)
	echo -n "Checking for service adeona "
	## Check status with checkproc(8), if process is running
	## checkproc will return with exit status 0.

	# Return value is slightly different for the status command:
	# 0 - service up and running
	# 1 - service dead, but /var/run/  pid  file exists
	# 2 - service dead, but /var/lock/ lock file exists
	# 3 - service not running (unused)
	# 4 - service status unknown :-(
	# 5--199 reserved (5--99 LSB, 100--149 distro, 150--199 appl.)
	
	# NOTE: checkproc returns LSB compliant status values.
	/sbin/checkproc $ADEONA_BIN
	# NOTE: rc_status knows that we called this init script with
	# "status" option and adapts its messages accordingly.
	rc_status -v
	;;
    *)
	echo "Usage: $0 {start|stop|status|try-restart|restart}"
	exit 1
	;;
esac
rc_exit
